@@ -25,7 +25,6 @@ import java.net.URISyntaxException;
 import java.security.KeyPair;
 import java.security.NoSuchAlgorithmException;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.apache.commons.cli.CommandLine;
@@ -45,6 +44,8 @@ import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.KeyPairAlgorithm;
 import org.mozilla.jss.crypto.KeyPairGenerator;
 import org.mozilla.jss.crypto.TokenException;
+import org.mozilla.jss.netscape.security.util.Utils;
+import org.mozilla.jss.netscape.security.x509.X500Name;
 import org.mozilla.jss.pkix.crmf.CertReqMsg;
 import org.mozilla.jss.pkix.crmf.CertRequest;
 import org.mozilla.jss.pkix.crmf.CertTemplate;
@@ -57,13 +58,9 @@ import org.mozilla.jss.util.Password;
 import com.netscape.certsrv.client.ClientConfig;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.system.ConfigurationRequest;
-import com.netscape.certsrv.system.ConfigurationResponse;
 import com.netscape.certsrv.system.SystemCertData;
 import com.netscape.certsrv.system.SystemConfigClient;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.util.Utils;
-
-import netscape.security.x509.X500Name;
 
 /**
  * @author alee
@@ -222,18 +219,7 @@ public class ConfigurationTest {
             System.exit(1);
         }
 
-        ConfigurationResponse response = client.configure(data);
-
-        System.out.println("adminCert: " + response.getAdminCert().getCert());
-        List<SystemCertData> certs = response.getSystemCerts();
-        Iterator<SystemCertData> iterator = certs.iterator();
-        while (iterator.hasNext()) {
-            SystemCertData cdata = iterator.next();
-            System.out.println("tag: " + cdata.getTag());
-            System.out.println("cert: " + cdata.getCert());
-            System.out.println("request: " + cdata.getRequest());
-        }
-
+        client.configure(data);
     }
 
     private static ConfigurationRequest constructCAData(String host, String port, String pin, String db_dir,
@@ -242,30 +228,15 @@ public class ConfigurationTest {
         ConfigurationRequest data = new ConfigurationRequest();
         data.setPin(pin);
         data.setSecurityDomainType(ConfigurationRequest.NEW_DOMAIN);
-        data.setSecurityDomainName("Testca2 security domain");
         data.setClone("false");
         data.setHierarchy("root");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test ca subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testca2");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testca2");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         // create system certs
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
         cert1.setTag("signing");
-        cert1.setKeyAlgorithm("SHA256withRSA");
         cert1.setKeySize("2048");
-        cert1.setKeyType("rsa");
         cert1.setNickname("signingCert testca");
-        cert1.setSigningAlgorithm("SHA256withRSA");
         cert1.setSubjectDN("CN=CA Signing Certificate");
         cert1.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
 
@@ -273,20 +244,15 @@ public class ConfigurationTest {
 
         SystemCertData cert2 = new SystemCertData();
         cert2.setTag("ocsp_signing");
-        cert2.setKeyAlgorithm("SHA256withRSA");
         cert2.setKeySize("2048");
-        cert2.setKeyType("rsa");
         cert2.setNickname("ocspSigningCert testca");
-        cert2.setSigningAlgorithm("SHA256withRSA");
         cert2.setSubjectDN("CN= CA OCSP Signing Certificate");
         cert2.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert2);
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testca");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -294,9 +260,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testca");
         cert4.setSubjectDN("CN=CA Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -304,17 +268,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testca");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=CA Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -331,17 +290,6 @@ public class ConfigurationTest {
 
         data.setClone("false");
         data.setHierarchy("join");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test subca subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testsubca");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testsubca");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         data.setIssuingCA("https://" + host + ":9224");
 
@@ -349,11 +297,8 @@ public class ConfigurationTest {
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
         cert1.setTag("signing");
-        cert1.setKeyAlgorithm("SHA256withRSA");
         cert1.setKeySize("2048");
-        cert1.setKeyType("rsa");
         cert1.setNickname("signingCert testsubca");
-        cert1.setSigningAlgorithm("SHA256withRSA");
         cert1.setSubjectDN("CN=SubCA Signing Certificate");
         cert1.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
 
@@ -361,20 +306,15 @@ public class ConfigurationTest {
 
         SystemCertData cert2 = new SystemCertData();
         cert2.setTag("ocsp_signing");
-        cert2.setKeyAlgorithm("SHA256withRSA");
         cert2.setKeySize("2048");
-        cert2.setKeyType("rsa");
         cert2.setNickname("ocspSigningCert testsubca");
-        cert2.setSigningAlgorithm("SHA256withRSA");
         cert2.setSubjectDN("CN= SubCA OCSP Signing Certificate");
         cert2.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert2);
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testsubca");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -382,9 +322,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testsubca");
         cert4.setSubjectDN("CN=SubCA Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -392,17 +330,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testsubca");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=SubCA Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -413,21 +346,9 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.NEW_DOMAIN);
-        data.setSecurityDomainName("External CA security domain");
 
         data.setClone("false");
         data.setHierarchy("join");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test external ca subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testexternalca");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testexternalca");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         data.setIssuingCA("External CA");
 
@@ -435,11 +356,8 @@ public class ConfigurationTest {
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
         cert1.setTag("signing");
-        cert1.setKeyAlgorithm("SHA256withRSA");
         cert1.setKeySize("2048");
-        cert1.setKeyType("rsa");
         cert1.setNickname("signingCert testexternalca");
-        cert1.setSigningAlgorithm("SHA256withRSA");
         cert1.setSubjectDN("CN=External CA Signing Certificate");
         cert1.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
 
@@ -447,20 +365,15 @@ public class ConfigurationTest {
 
         SystemCertData cert2 = new SystemCertData();
         cert2.setTag("ocsp_signing");
-        cert2.setKeyAlgorithm("SHA256withRSA");
         cert2.setKeySize("2048");
-        cert2.setKeyType("rsa");
         cert2.setNickname("ocspSigningCert testexternalca");
-        cert2.setSigningAlgorithm("SHA256withRSA");
         cert2.setSubjectDN("CN= External CA OCSP Signing Certificate");
         cert2.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert2);
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testexternalca");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -468,9 +381,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testexternalca");
         cert4.setSubjectDN("CN=External CA Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -478,17 +389,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testexternalca");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=SubCA Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -499,21 +405,9 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.NEW_DOMAIN);
-        data.setSecurityDomainName("External CA security domain");
 
         data.setClone("false");
         data.setHierarchy("join");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test external ca subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testexternalca");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testexternalca");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         data.setIssuingCA("External CA");
 
@@ -521,11 +415,8 @@ public class ConfigurationTest {
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
         cert1.setTag("signing");
-        cert1.setKeyAlgorithm("SHA256withRSA");
         cert1.setKeySize("2048");
-        cert1.setKeyType("rsa");
         cert1.setNickname("signingCert testexternalca");
-        cert1.setSigningAlgorithm("SHA256withRSA");
         cert1.setSubjectDN("CN=External CA Signing Certificate");
         cert1.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
 
@@ -541,20 +432,15 @@ public class ConfigurationTest {
 
         SystemCertData cert2 = new SystemCertData();
         cert2.setTag("ocsp_signing");
-        cert2.setKeyAlgorithm("SHA256withRSA");
         cert2.setKeySize("2048");
-        cert2.setKeyType("rsa");
         cert2.setNickname("ocspSigningCert testexternalca");
-        cert2.setSigningAlgorithm("SHA256withRSA");
         cert2.setSubjectDN("CN= External CA OCSP Signing Certificate");
         cert2.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert2);
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testexternalca");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -562,9 +448,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testexternalca");
         cert4.setSubjectDN("CN=External CA Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -572,17 +456,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testexternalca");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=SubCA Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -598,36 +477,19 @@ public class ConfigurationTest {
 
         data.setClone("true");
         data.setCloneUri("https://" + host + ":9224" );
-        data.setP12File("master.p12");
-        data.setP12Password("redhat123");
 
         data.setHierarchy("root");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test clone ca subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7494");
-        data.setBaseDN("o=testca2");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testca2");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         // create system certs
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testca");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert3);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -643,17 +505,6 @@ public class ConfigurationTest {
         data.setSecurityDomainPassword("redhat123");
 
         data.setClone("false");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test kra subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testkra22");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testkra");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         data.setIssuingCA("https://" + host + ":9224");
 
@@ -661,11 +512,8 @@ public class ConfigurationTest {
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
         cert1.setTag("transport");
-        cert1.setKeyAlgorithm("SHA256withRSA");
         cert1.setKeySize("2048");
-        cert1.setKeyType("rsa");
         cert1.setNickname("transportCert testkra");
-        cert1.setSigningAlgorithm("SHA256withRSA");
         cert1.setSubjectDN("CN=KRA Transport Certificate");
         cert1.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
 
@@ -673,20 +521,15 @@ public class ConfigurationTest {
 
         SystemCertData cert2 = new SystemCertData();
         cert2.setTag("storage");
-        cert2.setKeyAlgorithm("SHA256withRSA");
         cert2.setKeySize("2048");
-        cert2.setKeyType("rsa");
         cert2.setNickname("storageCert testkra");
-        cert2.setSigningAlgorithm("SHA256withRSA");
         cert2.setSubjectDN("CN= KRA Storage Certificate");
         cert2.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert2);
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testkra");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -694,9 +537,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testkra");
         cert4.setSubjectDN("CN=KRA Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -704,17 +545,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testkra");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=KRA Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -730,17 +566,6 @@ public class ConfigurationTest {
         data.setSecurityDomainPassword("redhat123");
 
         data.setClone("false");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test ocsp subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testocsp22");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testocsp22");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         data.setIssuingCA("https://" + host + ":9224");
 
@@ -748,11 +573,8 @@ public class ConfigurationTest {
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
         SystemCertData cert1 = new SystemCertData();
         cert1.setTag("signing");
-        cert1.setKeyAlgorithm("SHA256withRSA");
         cert1.setKeySize("2048");
-        cert1.setKeyType("rsa");
         cert1.setNickname("ocspSigningCert testocsp");
-        cert1.setSigningAlgorithm("SHA256withRSA");
         cert1.setSubjectDN("CN=OCSP Signing Certificate");
         cert1.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
 
@@ -760,9 +582,7 @@ public class ConfigurationTest {
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testocsp");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -770,9 +590,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testocsp");
         cert4.setSubjectDN("CN=OCSP Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -780,17 +598,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testocsp");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=OCSP Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
@@ -806,17 +619,6 @@ public class ConfigurationTest {
         data.setSecurityDomainPassword("redhat123");
 
         data.setClone("false");
-        data.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
-        data.setSubsystemName("test tks subsystem");
-
-        data.setDsHost(host);
-        data.setDsPort("7389");
-        data.setBaseDN("o=testtks22");
-        data.setBindDN("cn=Directory Manager");
-        data.setDatabase("o=testtks22");
-        data.setBindpwd("redhat123");
-        data.setRemoveData("true");
-        data.setSecureConn("false");
 
         data.setIssuingCA("https://" + host + ":9224");
 
@@ -825,9 +627,7 @@ public class ConfigurationTest {
 
         SystemCertData cert3 = new SystemCertData();
         cert3.setTag("sslserver");
-        cert3.setKeyAlgorithm("SHA256withRSA");
         cert3.setKeySize("2048");
-        cert3.setKeyType("rsa");
         cert3.setNickname("sslServerCert testtks");
         cert3.setSubjectDN("CN=" + host);
         cert3.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -835,9 +635,7 @@ public class ConfigurationTest {
 
         SystemCertData cert4 = new SystemCertData();
         cert4.setTag("subsystem");
-        cert4.setKeyAlgorithm("SHA256withRSA");
         cert4.setKeySize("2048");
-        cert4.setKeyType("rsa");
         cert4.setNickname("subsystemCert testtks");
         cert4.setSubjectDN("CN=TKS Subsystem Certificate");
         cert4.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
@@ -845,17 +643,12 @@ public class ConfigurationTest {
 
         SystemCertData cert5 = new SystemCertData();
         cert5.setTag("audit_signing");
-        cert5.setKeyAlgorithm("SHA256withRSA");
         cert5.setKeySize("2048");
-        cert5.setKeyType("rsa");
         cert5.setNickname("auditSigningCert testtks");
-        cert5.setSigningAlgorithm("SHA256withRSA");
         cert5.setSubjectDN("CN=TKS Audit Signing Certificate");
         cert5.setToken(CryptoUtil.INTERNAL_TOKEN_FULL_NAME);
         systemCerts.add(cert5);
 
-        data.setSystemCerts(systemCerts);
-
         return data;
     }
 
