@@ -19,17 +19,22 @@
 package org.dogtagpki.server.kra;
 
 import com.netscape.certsrv.base.EBaseException;
+import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
+import com.netscape.cms.servlet.csadmin.Configurator;
 import com.netscape.cmscore.apps.CMSEngine;
-import com.netscape.cmscore.apps.SubsystemInfo;
 import com.netscape.cmscore.selftests.SelfTestSubsystem;
 import com.netscape.kra.KeyRecoveryAuthority;
 
 public class KRAEngine extends CMSEngine {
 
-    public KRAEngine() {
+    public KRAEngine() throws Exception {
         super("KRA");
     }
 
+    public Configurator createConfigurator() throws Exception {
+        return new KRAConfigurator(this);
+    }
+
     protected void loadSubsystems() throws EBaseException {
 
         super.loadSubsystems();
@@ -38,11 +43,22 @@ public class KRAEngine extends CMSEngine {
             // Disable some subsystems before database initialization
             // in pre-op mode to prevent misleading exceptions.
 
-            SubsystemInfo si = dynSubsystems.get(KeyRecoveryAuthority.ID);
-            si.enabled = false;
+            setSubsystemEnabled(KeyRecoveryAuthority.ID, false);
+            setSubsystemEnabled(SelfTestSubsystem.ID, false);
+        }
+    }
 
-            si = dynSubsystems.get(SelfTestSubsystem.ID);
-            si.enabled = false;
+    public void startupSubsystems() throws EBaseException {
+
+        super.startupSubsystems();
+
+        IKeyRecoveryAuthority kra = (IKeyRecoveryAuthority) getSubsystem(IKeyRecoveryAuthority.ID);
+        if (!isPreOpMode()) {
+            logger.debug("CMSEngine: checking request serial number ranges for the KRA");
+            kra.getRequestQueue().getRequestRepository().checkRanges();
+
+            logger.debug("CMSEngine: checking key serial number ranges");
+            kra.getKeyRepository().checkRanges();
         }
     }
 }
