@@ -19,16 +19,16 @@ package com.netscape.cms.evaluators;
 
 import java.util.Arrays;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.util.Utils;
+
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.evaluators.IAccessEvaluator;
-import com.netscape.certsrv.logging.ILogger;
-import com.netscape.certsrv.usrgrp.IUGSubsystem;
 import com.netscape.certsrv.usrgrp.IUser;
-import com.netscape.cms.logging.Logger;
-import com.netscape.cmsutil.util.Utils;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.usrgrp.UGSubsystem;
 
 /**
  * A class represents a group acls evaluator.
@@ -37,20 +37,23 @@ import com.netscape.cmsutil.util.Utils;
  * @version $Revision$, $Date$
  */
 public class GroupAccessEvaluator implements IAccessEvaluator {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(GroupAccessEvaluator.class);
+
     private String mType = "group";
-    private IUGSubsystem mUG = null;
+    private UGSubsystem mUG = null;
     private String mDescription = "group membership evaluator";
-    private Logger mLogger = Logger.getLogger();
 
     /**
      * Class constructor.
      */
     public GroupAccessEvaluator() {
 
-        mUG = (IUGSubsystem) CMS.getSubsystem(CMS.SUBSYSTEM_UG);
+        CMSEngine engine = CMS.getCMSEngine();
+        mUG = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
 
         if (mUG == null) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("EVALUTOR_UG_NULL"));
+            logger.warn("GroupAccessEvaluator: " + CMS.getLogMessage("EVALUTOR_UG_NULL"));
         }
     }
 
@@ -58,7 +61,7 @@ public class GroupAccessEvaluator implements IAccessEvaluator {
      * initialization. nothing for now.
      */
     public void init() {
-        CMS.debug("GroupAccessEvaluator: init");
+        logger.debug("GroupAccessEvaluator: init");
     }
 
     /**
@@ -108,12 +111,11 @@ public class GroupAccessEvaluator implements IAccessEvaluator {
             if (uid == null) {
                 uid = authToken.getInString(IAuthToken.UID);
                 if (uid == null) {
-                    CMS.debug("GroupAccessEvaluator: evaluate: uid null");
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("EVALUTOR_UID_NULL"));
+                    logger.warn("GroupAccessEvaluator: " + CMS.getLogMessage("EVALUTOR_UID_NULL"));
                     return false;
                 }
             }
-            CMS.debug("GroupAccessEvaluator: evaluate: uid=" + uid + " value=" + value);
+            logger.debug("GroupAccessEvaluator: evaluate: uid=" + uid + " value=" + value);
 
             String[] groups = authToken.getInStringArray(IAuthToken.GROUPS);
             if (groups != null) {
@@ -123,12 +125,12 @@ public class GroupAccessEvaluator implements IAccessEvaluator {
                 else if (op.equals("!="))
                     return !matched;
             } else {
-                CMS.debug("GroupAccessEvaluator: evaluate: no groups in authToken");
+                logger.debug("GroupAccessEvaluator: evaluate: no groups in authToken");
                 IUser id = null;
                 try {
                     id = mUG.getUser(uid);
                 } catch (EBaseException e) {
-                    CMS.debug("GroupAccessEvaluator: " + e.toString());
+                    logger.warn("GroupAccessEvaluator: " + e.getMessage(), e);
                     return false;
                 }
 
@@ -161,7 +163,7 @@ public class GroupAccessEvaluator implements IAccessEvaluator {
             IUser id = (IUser) mSC.get(SessionContext.USER);
 
             if (id == null) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("EVALUTOR_UID_NULL"));
+                logger.warn("GroupAccessEvaluator: " + CMS.getLogMessage("EVALUTOR_UID_NULL"));
                 return false;
             }
             if (op.equals("="))
@@ -173,12 +175,4 @@ public class GroupAccessEvaluator implements IAccessEvaluator {
 
         return false;
     }
-
-    private void log(int level, String msg) {
-        if (mLogger == null)
-            return;
-        mLogger.log(ILogger.EV_SYSTEM, ILogger.S_ACLS,
-                level, "GroupAccessEvaluator: " + msg);
-    }
-
 }
