@@ -22,15 +22,19 @@ import java.io.IOException;
 import java.util.Locale;
 import java.util.StringTokenizer;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.x509.CertificateSubjectName;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CertInfo;
+
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.ldap.ILdapConnFactory;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.profile.IProfile;
 import com.netscape.certsrv.property.Descriptor;
 import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.property.IDescriptor;
 import com.netscape.certsrv.request.IRequest;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.ldapconn.LdapAnonConnFactory;
 import com.netscape.cmsutil.ldap.LDAPUtil;
 
@@ -39,9 +43,6 @@ import netscape.ldap.LDAPConnection;
 import netscape.ldap.LDAPEntry;
 import netscape.ldap.LDAPSearchResults;
 import netscape.ldap.LDAPv2;
-import netscape.security.x509.CertificateSubjectName;
-import netscape.security.x509.X500Name;
-import netscape.security.x509.X509CertInfo;
 
 /**
  * This class implements an enrollment default policy
@@ -52,6 +53,8 @@ import netscape.security.x509.X509CertInfo;
  */
 public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(nsTokenUserKeySubjectNameDefault.class);
+
     public static final String PROP_LDAP = "ldap";
     public static final String PROP_PARAMS = "params";
     public static final String CONFIG_DNPATTERN = "dnpattern";
@@ -85,8 +88,7 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
     /* ldap base dn */
     protected String mBaseDN = null;
 
-    /* factory of anonymous ldap connections */
-    protected ILdapConnFactory mConnFactory = null;
+    protected LdapAnonConnFactory mConnFactory;
 
     /* the list of LDAP attributes with string values to retrieve to
      * form the subject dn. */
@@ -126,7 +128,7 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
     }
 
     public IDescriptor getConfigDescriptor(Locale locale, String name) {
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in getConfigDescriptor, name=" + name);
+        logger.debug("nsTokenUserKeySubjectNameDefault: in getConfigDescriptor, name=" + name);
         if (name.equals(CONFIG_DNPATTERN)) {
             return new Descriptor(IDescriptor.STRING,
                     null, null, CMS.getUserMessage(locale,
@@ -186,7 +188,7 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
     }
 
     public IDescriptor getValueDescriptor(Locale locale, String name) {
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in getValueDescriptor name=" + name);
+        logger.debug("nsTokenUserKeySubjectNameDefault: in getValueDescriptor name=" + name);
 
         if (name.equals(VAL_NAME)) {
             return new Descriptor(IDescriptor.STRING,
@@ -203,7 +205,7 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
             X509CertInfo info, String value)
             throws EPropertyException {
 
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in setValue, value=" + value);
+        logger.debug("nsTokenUserKeySubjectNameDefault: in setValue, value=" + value);
 
         if (name == null) {
             throw new EPropertyException(CMS.getUserMessage(
@@ -215,16 +217,16 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
             try {
                 x500name = new X500Name(value);
             } catch (IOException e) {
-                CMS.debug("nsTokenUserKeySubjectNameDefault: setValue " + e.toString());
+                logger.warn("nsTokenUserKeySubjectNameDefault: setValue " + e.getMessage(), e);
                 // failed to build x500 name
             }
-            CMS.debug("nsTokenUserKeySubjectNameDefault: setValue name=" + x500name);
+            logger.debug("nsTokenUserKeySubjectNameDefault: setValue name=" + x500name);
             try {
                 info.set(X509CertInfo.SUBJECT,
                         new CertificateSubjectName(x500name));
             } catch (Exception e) {
                 // failed to insert subject name
-                CMS.debug("nsTokenUserKeySubjectNameDefault: setValue " + e.toString());
+                logger.error("nsTokenUserKeySubjectNameDefault: setValue " + e.getMessage(), e);
                 throw new EPropertyException(CMS.getUserMessage(
                             locale, "CMS_INVALID_PROPERTY", name));
             }
@@ -237,7 +239,7 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
     public String getValue(String name, Locale locale,
             X509CertInfo info)
             throws EPropertyException {
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in getValue, name=" + name);
+        logger.debug("nsTokenUserKeySubjectNameDefault: in getValue, name=" + name);
         if (name == null) {
             throw new EPropertyException(CMS.getUserMessage(
                         locale, "CMS_INVALID_PROPERTY", name));
@@ -246,14 +248,14 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
             CertificateSubjectName sn = null;
 
             try {
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getValue info=" + info);
+                logger.debug("nsTokenUserKeySubjectNameDefault: getValue info=" + info);
                 sn = (CertificateSubjectName)
                         info.get(X509CertInfo.SUBJECT);
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getValue name=" + sn);
+                logger.debug("nsTokenUserKeySubjectNameDefault: getValue name=" + sn);
                 return sn.toString();
             } catch (Exception e) {
                 // nothing
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getValue " + e.toString());
+                logger.warn("nsTokenUserKeySubjectNameDefault: getValue " + e.getMessage(), e);
 
             }
             throw new EPropertyException(CMS.getUserMessage(
@@ -265,7 +267,7 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
     }
 
     public String getText(Locale locale) {
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in getText");
+        logger.debug("nsTokenUserKeySubjectNameDefault: in getText");
         return CMS.getUserMessage(locale, "CMS_PROFILE_SUBJECT_NAME",
                 getConfig(CONFIG_DNPATTERN));
     }
@@ -275,7 +277,10 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
         if (mldapInitialized == true)
             return;
 
-        CMS.debug("nsTokenUserKeySubjectNameDefault: ldapInit(): begin");
+        logger.debug("nsTokenUserKeySubjectNameDefault: ldapInit(): begin");
+
+        CMSEngine engine = CMS.getCMSEngine();
+        IConfigStore cs = engine.getConfigStore();
 
         try {
             // cfu - XXX do more error handling here later
@@ -288,8 +293,9 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
                 return;
 
             mBaseDN = mParamsConfig.getString(CONFIG_LDAP_BASEDN, null);
+
             mConnFactory = new LdapAnonConnFactory("nsTokenUserKeySubjectNameDefault");
-            mConnFactory.init(mLdapConfig);
+            mConnFactory.init(cs, mLdapConfig);
 
             /* initialize dn pattern */
             String pattern = mParamsConfig.getString(CONFIG_DNPATTERN, null);
@@ -310,10 +316,10 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
                     mLdapStringAttrs[i] = ((String) pAttrs.nextElement()).trim();
                 }
             }
-            CMS.debug("nsTokenUserKeySubjectNameDefault: ldapInit(): done");
+            logger.debug("nsTokenUserKeySubjectNameDefault: ldapInit(): done");
             mldapInitialized = true;
         } catch (Exception e) {
-            CMS.debug("nsTokenUserKeySubjectNameDefault: ldapInit(): " + e.toString());
+            logger.error("nsTokenUserKeySubjectNameDefault: ldapInit(): " + e.getMessage(), e);
             // throw EProfileException...
             throw new EProfileException("ldap init failure: " + e.toString());
         }
@@ -325,19 +331,19 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
     public void populate(IRequest request, X509CertInfo info)
             throws EProfileException {
         X500Name name = null;
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in populate");
+        logger.debug("nsTokenUserKeySubjectNameDefault: in populate");
         ldapInit();
         try {
             // cfu - this goes to ldap
             String subjectName = getSubjectName(request);
-            CMS.debug("subjectName=" + subjectName);
+            logger.debug("subjectName=" + subjectName);
             if (subjectName == null || subjectName.equals(""))
                 return;
 
             name = new X500Name(subjectName);
         } catch (IOException e) {
             // failed to build x500 name
-            CMS.debug("nsTokenUserKeySubjectNameDefault: populate " + e.toString());
+            logger.warn("nsTokenUserKeySubjectNameDefault: populate " + e.getMessage(), e);
         }
         if (name == null) {
             // failed to build x500 name
@@ -347,14 +353,14 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
                     new CertificateSubjectName(name));
         } catch (Exception e) {
             // failed to insert subject name
-            CMS.debug("nsTokenUserKeySubjectNameDefault: populate " + e.toString());
+            logger.warn("nsTokenUserKeySubjectNameDefault: populate " + e.getMessage(), e);
         }
     }
 
     private String getSubjectName(IRequest request)
             throws EProfileException, IOException {
 
-        CMS.debug("nsTokenUserKeySubjectNameDefault: in getSubjectName");
+        logger.debug("nsTokenUserKeySubjectNameDefault: in getSubjectName");
 
         String pattern = getConfig(CONFIG_DNPATTERN);
         if (pattern == null || pattern.equals("")) {
@@ -364,9 +370,9 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
 
         if (mldapInitialized == false) {
             if (request != null) {
-                CMS.debug("pattern = " + pattern);
+                logger.debug("pattern = " + pattern);
                 sbjname = mapPattern(request, pattern);
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): subject name mapping done");
+                logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): subject name mapping done");
             }
             return sbjname;
         }
@@ -383,20 +389,20 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
         try {
             if (mConnFactory == null) {
                 conn = null;
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): no LDAP connection");
+                logger.error("nsTokenUserKeySubjectNameDefault: getSubjectName(): no LDAP connection");
                 throw new EProfileException("no LDAP connection");
             } else {
                 conn = mConnFactory.getConn();
                 if (conn == null) {
-                    CMS.debug("nsTokenUserKeySubjectNameDefault::getSubjectName() - " +
+                    logger.error("nsTokenUserKeySubjectNameDefault::getSubjectName() - " +
                                "no LDAP connection");
                     throw new EProfileException("no LDAP connection");
                 }
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): got LDAP connection");
+                logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): got LDAP connection");
             }
             // retrieve the attributes
             // get user dn.
-            CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): about to search with basedn = " + mBaseDN);
+            logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): about to search with basedn = " + mBaseDN);
             LDAPSearchResults res = conn.search(mBaseDN,
                     LDAPv2.SCOPE_SUB, "(" + searchName + "=" + request.getExtDataInString("uid") + ")", null, false);
 
@@ -405,21 +411,21 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
 
                 userdn = entry.getDN();
             } else {// put into property file later - cfu
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): " + searchName + " does not exist");
+                logger.error("nsTokenUserKeySubjectNameDefault: getSubjectName(): " + searchName + " does not exist");
                 throw new EProfileException("id does not exist");
             }
-            CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): retrieved entry for "
+            logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): retrieved entry for "
                     + searchName + " = " + request.getExtDataInString("uid"));
 
             LDAPEntry entry = null;
-            CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): about to search with "
+            logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): about to search with "
                     + mLdapStringAttrs.length + " attributes");
             LDAPSearchResults results =
                     conn.search(userdn, LDAPv2.SCOPE_BASE, "objectclass=*",
                             mLdapStringAttrs, false);
 
             if (!results.hasMoreElements()) {
-                CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): no attributes");
+                logger.error("nsTokenUserKeySubjectNameDefault: getSubjectName(): no attributes");
                 throw new EProfileException("no ldap attributes found");
             }
             entry = results.next();
@@ -429,19 +435,19 @@ public class nsTokenUserKeySubjectNameDefault extends EnrollDefault {
                         entry.getAttribute(mLdapStringAttrs[i]);
                 if (la != null) {
                     String[] sla = la.getStringValueArray();
-                    CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): got attribute: "
+                    logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): got attribute: "
                             + mLdapStringAttrs[i] +
                             "=" + LDAPUtil.escapeRDNValue(sla[0]));
                     request.setExtData(mLdapStringAttrs[i], LDAPUtil.escapeRDNValue(sla[0]));
                 }
             }
-            CMS.debug("pattern = " + pattern);
+            logger.debug("pattern = " + pattern);
             sbjname = mapPattern(request, pattern);
-            CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): subject name mapping done");
-            CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): attributes set in request");
+            logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): subject name mapping done");
+            logger.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): attributes set in request");
 
         } catch (Exception e) {
-            CMS.debug("nsTokenUserKeySubjectNameDefault: getSubjectName(): " + e.toString());
+            logger.error("nsTokenUserKeySubjectNameDefault: getSubjectName(): " + e.getMessage(), e);
             throw new EProfileException("getSubjectName() failure: " + e.toString());
         } finally {
             try {
