@@ -8,8 +8,8 @@ import java.util.List;
 
 import org.apache.catalina.realm.RealmBase;
 import org.apache.commons.lang.StringUtils;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.authentication.IAuthManager;
 import com.netscape.certsrv.authentication.IAuthSubsystem;
 import com.netscape.certsrv.authentication.IAuthToken;
@@ -20,13 +20,13 @@ import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.AuthEvent;
 import com.netscape.certsrv.usrgrp.EUsrGrpException;
 import com.netscape.certsrv.usrgrp.IGroup;
-import com.netscape.certsrv.usrgrp.IUGSubsystem;
 import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.common.AuthCredentials;
-
-import netscape.security.x509.X509CertImpl;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.usrgrp.UGSubsystem;
 
 /**
  *  PKI Realm
@@ -50,11 +50,12 @@ public class PKIRealm extends RealmBase {
     public Principal authenticate(String username, String password) {
         logger.info("Authenticating user " + username + " with password.");
 
+        CMSEngine engine = CMS.getCMSEngine();
         String auditSubjectID = ILogger.UNIDENTIFIED;
         String attemptedAuditUID = username;
 
         try {
-            IAuthSubsystem authSub = (IAuthSubsystem) CMS.getSubsystem(CMS.SUBSYSTEM_AUTH);
+            IAuthSubsystem authSub = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
             IAuthManager authMgr = authSub.getAuthManager(IAuthSubsystem.PASSWDUSERDB_AUTHMGR_ID);
 
             AuthCredentials creds = new AuthCredentials();
@@ -92,6 +93,7 @@ public class PKIRealm extends RealmBase {
         // in cert based auth, subject id from cert has already passed SSL authentication
         // what remains is to see if the user exists in the internal user db
         // therefore both auditSubjectID and attemptedAuditUID are the same
+        CMSEngine engine = CMS.getCMSEngine();
         String auditSubjectID = getAuditUserfromCert(certs[0]);
         String attemptedAuditUID = auditSubjectID;
 
@@ -101,10 +103,10 @@ public class PKIRealm extends RealmBase {
                 X509Certificate cert = certs[i];
                 logger.info(" - " + cert.getSubjectDN());
 
-                // Convert sun.security.x509.X509CertImpl to netscape.security.x509.X509CertImpl
+                // Convert sun.security.x509.X509CertImpl to org.mozilla.jss.netscape.security.x509.X509CertImpl
                 certImpls[i] = new X509CertImpl(cert.getEncoded());
             }
-            IAuthSubsystem authSub = (IAuthSubsystem) CMS.getSubsystem(CMS.SUBSYSTEM_AUTH);
+            IAuthSubsystem authSub = (IAuthSubsystem) engine.getSubsystem(IAuthSubsystem.ID);
             IAuthManager authMgr = authSub.getAuthManager(IAuthSubsystem.CERTUSERDB_AUTHMGR_ID);
 
             AuthCredentials creds = new AuthCredentials();
@@ -165,7 +167,8 @@ public class PKIRealm extends RealmBase {
     }
 
     protected IUser getUser(String username) throws EUsrGrpException {
-        IUGSubsystem ugSub = (IUGSubsystem) CMS.getSubsystem(CMS.SUBSYSTEM_UG);
+        CMSEngine engine = CMS.getCMSEngine();
+        UGSubsystem ugSub = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
         IUser user = ugSub.getUser(username);
         logger.info("User DN: " + user.getUserDN());
         return user;
@@ -175,7 +178,8 @@ public class PKIRealm extends RealmBase {
 
         List<String> roles = new ArrayList<String>();
 
-        IUGSubsystem ugSub = (IUGSubsystem) CMS.getSubsystem(CMS.SUBSYSTEM_UG);
+        CMSEngine engine = CMS.getCMSEngine();
+        UGSubsystem ugSub = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
         Enumeration<IGroup> groups = ugSub.findGroupsByUser(user.getUserDN(), null);
 
         logger.info("Roles:");
