@@ -21,19 +21,18 @@ import java.util.Enumeration;
 import java.util.Hashtable;
 import java.util.StringTokenizer;
 
-import com.netscape.certsrv.apps.CMS;
+import org.mozilla.jss.netscape.security.util.DerValue;
+import org.mozilla.jss.netscape.security.util.ObjectIdentifier;
+import org.mozilla.jss.netscape.security.x509.AVAValueConverter;
+import org.mozilla.jss.netscape.security.x509.DirStrConverter;
+import org.mozilla.jss.netscape.security.x509.X500NameAttrMap;
+
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.cms.logging.Logger;
-import com.netscape.cmscore.util.Debug;
-
-import netscape.security.util.DerValue;
-import netscape.security.util.ObjectIdentifier;
-import netscape.security.x509.AVAValueConverter;
-import netscape.security.x509.DirStrConverter;
-import netscape.security.x509.X500NameAttrMap;
+import com.netscape.cmscore.apps.CMS;
 
 /**
  * Subsystem for configuring X500Name related things.
@@ -48,6 +47,8 @@ import netscape.security.x509.X500NameAttrMap;
  */
 public class X500NameSubsystem implements ISubsystem {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(X500NameSubsystem.class);
+
     private IConfigStore mConfig = null;
     public static final String ID = "X500Name";
     private String mId = ID;
@@ -108,19 +109,19 @@ public class X500NameSubsystem implements ISubsystem {
      * </pre>
      *
      * The value converter class converts a string to a ASN.1 value. It must implement
-     * netscape.security.x509.AVAValueConverter interface. Converter classes provided in CMS are:
+     * org.mozilla.jss.netscape.security.x509.AVAValueConverter interface. Converter classes provided in CMS are:
      *
      * <pre>
-     *     netscape.security.x509.PrintableConverter -
+     *     org.mozilla.jss.netscape.security.x509.PrintableConverter -
      * 		Converts to a Printable String value. String must have only
      * 		printable characters.
-     *     netscape.security.x509.IA5StringConverter -
+     *     org.mozilla.jss.netscape.security.x509.IA5StringConverter -
      * 		Converts to a IA5String value. String must have only IA5String
      * 		characters.
-     *     netscape.security.x509.DirStrConverter -
+     *     org.mozilla.jss.netscape.security.x509.DirStrConverter -
      * 		Converts to a Directory (v3) String. String is expected to
      * 		be in Directory String format according to rfc2253.
-     *     netscape.security.x509.GenericValueConverter -
+     *     org.mozilla.jss.netscape.security.x509.GenericValueConverter -
      * 		Converts string character by character in the following order
      * 		from smaller character sets to broadest character set.
      * 			Printable, IA5String, BMPString, Universal String.
@@ -135,9 +136,7 @@ public class X500NameSubsystem implements ISubsystem {
     public synchronized void init(ISubsystem owner, IConfigStore config)
             throws EBaseException {
         mLogger = Logger.getLogger();
-        if (Debug.ON) {
-            Debug.trace(ID + " started");
-        }
+        logger.trace(ID + " started");
         mConfig = config;
 
         // get order for encoding directory strings if any.
@@ -174,9 +173,7 @@ public class X500NameSubsystem implements ISubsystem {
                         CMS.getUserMessage("CMS_BASE_LOAD_CLASS_FAILED", className, e.toString()));
             }
             globalMap.addNameOID(name, oid, convClass);
-            if (Debug.ON) {
-                Debug.trace(ID + ": Loaded " + name + " " + oid + " " + className);
-            }
+            logger.trace(ID + ": Loaded " + name + " " + oid + " " + className);
         }
     }
 
@@ -190,10 +187,10 @@ public class X500NameSubsystem implements ISubsystem {
         String order = mConfig.getString(PROP_DIR_STR_ENCODING_ORDER, null);
 
         if (order == null || order.length() == 0) { // nothing.
-            CMS.debug(method + "X500Name.directoryStringEncodingOrder not specified in config; Using default order in DirStrConverter.");
+            logger.debug(method + "X500Name.directoryStringEncodingOrder not specified in config; Using default order in DirStrConverter.");
             return;
         }
-        CMS.debug(method + "X500Name.directoryStringEncodingOrder specified in config: " + order);
+        logger.debug(method + "X500Name.directoryStringEncodingOrder specified in config: " + order);
 
         StringTokenizer toker = new StringTokenizer(order, ", \t");
         int numTokens = toker.countTokens();
