@@ -40,7 +40,7 @@ class MigrateCLI(pki.cli.CLI):
         self.parser = etree.XMLParser(remove_blank_text=True)
 
     def print_help(self):
-        print('Usage: pki-server migrate [OPTIONS]')
+        print('Usage: pki-server migrate [OPTIONS] [<instance ID>]')
         print()
         print('  -i, --instance <instance ID> Instance ID.')
         print('      --tomcat <version>       Use the specified Tomcat version.')
@@ -51,7 +51,7 @@ class MigrateCLI(pki.cli.CLI):
 
     def execute(self, argv):
         try:
-            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+            opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
                 'tomcat=', 'verbose', 'debug', 'help'])
 
@@ -89,6 +89,9 @@ class MigrateCLI(pki.cli.CLI):
         if not tomcat_version:
             tomcat_version = pki.server.Tomcat.get_version()
 
+        if len(args) > 0:
+            instance_name = args[0]
+
         if instance_name:
 
             instance = pki.server.PKIInstance(instance_name)
@@ -116,6 +119,9 @@ class MigrateCLI(pki.cli.CLI):
 
     def migrate_nssdb(self, instance):
 
+        if not os.path.exists(instance.nssdb_dir):
+            return
+
         if self.verbose:
             print('Migrating %s instance to NSS SQL database' % instance.name)
 
@@ -151,8 +157,6 @@ class MigrateCLI(pki.cli.CLI):
             'pki.xml')
         self.migrate_context_xml(pki_context_xml, tomcat_version)
 
-        self.migrate_tomcat_libraries(instance)
-
     def migrate_server_xml(self, instance, filename, tomcat_version):
         if self.verbose:
             print('Migrating %s' % filename)
@@ -391,8 +395,6 @@ class MigrateCLI(pki.cli.CLI):
         if self.debug:
             print('* updating secure Connector')
 
-        full_name = instance.get_sslserver_cert_nickname()
-
         connectors = server.findall('Service/Connector')
         for connector in connectors:
 
@@ -409,6 +411,8 @@ class MigrateCLI(pki.cli.CLI):
             connector.set('keystoreProvider', 'Mozilla-JSS')
             connector.attrib.pop('keystoreFile', None)
             connector.attrib.pop('keystorePassFile', None)
+
+            full_name = instance.get_sslserver_cert_nickname()
             connector.set('keyAlias', full_name)
 
             connector.set('trustManagerClassName', 'org.dogtagpki.tomcat.PKITrustManager')
@@ -452,14 +456,13 @@ class MigrateCLI(pki.cli.CLI):
         if self.debug:
             print('* adding SSLHostConfig')
 
-        full_name = instance.get_sslserver_cert_nickname()
-
         connectors = server.findall('Service/Connector')
         for connector in connectors:
 
             if connector.get('secure') != 'true':
                 continue
 
+            connector.set('sslImplementationName', 'org.dogtagpki.tomcat.JSSImplementation')
             connector.attrib.pop('sslProtocol', None)
             connector.attrib.pop('clientAuth', None)
             connector.attrib.pop('keystoreType', None)
@@ -475,7 +478,7 @@ class MigrateCLI(pki.cli.CLI):
 
             sslHostConfig.set('sslProtocol', 'SSL')
             sslHostConfig.set('certificateVerification', 'optional')
-            sslHostConfig.set('trustManagerClassName', 'org.dogtagpki.tomcat.PKITrustManager')
+            sslHostConfig.attrib.pop('trustManagerClassName', None)
 
             certificates = sslHostConfig.findall('Certificate')
             if len(certificates) > 0:
@@ -485,6 +488,8 @@ class MigrateCLI(pki.cli.CLI):
 
             certificate.set('certificateKeystoreType', 'pkcs11')
             certificate.set('certificateKeystoreProvider', 'Mozilla-JSS')
+
+            full_name = instance.get_sslserver_cert_nickname()
             certificate.set('certificateKeyAlias', full_name)
 
     def migrate_subsystems(self, instance, tomcat_version):
@@ -551,37 +556,6 @@ class MigrateCLI(pki.cli.CLI):
 
         resources.set('allowLinking', 'true')
 
-    def migrate_tomcat_libraries(self, instance):
-        # remove old links
-        for filename in os.listdir(instance.lib_dir):
-
-            path = os.path.join(instance.lib_dir, filename)
-
-            if self.verbose:
-                print('Removing %s' % path)
-
-            os.remove(path)
-
-        tomcat_dir = '/usr/share/tomcat/lib'
-
-        # create new links
-        for filename in os.listdir(tomcat_dir):
-
-            source = os.path.join(tomcat_dir, filename)
-            dest = os.path.join(instance.lib_dir, filename)
-            self.create_link(instance, source, dest)
-
-        # slf4j-api.jar
-        source = '/usr/share/pki/server/lib/slf4j-api.jar'
-        dest = os.path.join(instance.lib_dir, 'slf4j-api.jar')
-        self.create_link(instance, source, dest)
-
-        # slf4j-jdk14.jar
-        source = '/usr/share/pki/server/lib/slf4j-jdk14.jar'
-        dest = os.path.join(instance.lib_dir, 'slf4j-jdk14.jar')
-        if os.path.islink(source):
-            self.create_link(instance, source, dest)
-
     def create_link(self, instance, source, dest):
 
         if self.verbose:
