@@ -30,6 +30,7 @@ import tempfile
 import pki.cli
 import pki.server.cli.audit
 import pki.server.cli.config
+import pki.server.cli.db
 
 
 class OCSPCLI(pki.cli.CLI):
@@ -41,6 +42,7 @@ class OCSPCLI(pki.cli.CLI):
         self.add_module(OCSPCloneCLI())
         self.add_module(pki.server.cli.audit.AuditCLI(self))
         self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBCLI(self))
 
 
 class OCSPCloneCLI(pki.cli.CLI):
