@@ -23,13 +23,13 @@ from __future__ import absolute_import
 import logging
 import os
 
+import pki
+
 # PKI Deployment Imports
 from .. import pkiconfig as config
 from .. import pkiscriptlet
 
-logger = logging.LoggerAdapter(
-    logging.getLogger('webapp'),
-    extra={'indent': ''})
+logger = logging.getLogger('webapp')
 
 
 # PKI Web Application Deployment Scriptlet
@@ -40,7 +40,10 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             logger.info('Skipping webapp creation')
             return
 
-        logger.info('Creating webapp')
+        logger.info('Deploying /%s web application', deployer.mdict['pki_subsystem'].lower())
+
+        instance = pki.server.PKIInstance(deployer.mdict['pki_instance_name'])
+        instance.load()
 
         # Create subsystem webapps folder to store custom webapps:
         # <instance>/<subsystem>/webapps.
@@ -52,13 +55,8 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             deployer.mdict['pki_tomcat_subsystem_webapps_path'])
 
         # Deploy web application directly from /usr/share/pki.
-        deployer.deploy_webapp(
+        instance.deploy_webapp(
             deployer.mdict['pki_subsystem'].lower(),
-            os.path.join(
-                config.PKI_DEPLOYMENT_SOURCE_ROOT,
-                deployer.mdict['pki_subsystem'].lower(),
-                "webapps",
-                deployer.mdict['pki_subsystem'].lower()),
             os.path.join(
                 config.PKI_DEPLOYMENT_SOURCE_ROOT,
                 deployer.mdict['pki_subsystem'].lower(),
@@ -69,7 +67,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
     def destroy(self, deployer):
 
-        logger.info('Removing webapp')
+        logger.info('Undeploying /%s web application', deployer.mdict['pki_subsystem'].lower())
 
         # Delete <instance>/Catalina/localhost/<subsystem>.xml
         deployer.file.delete(
