@@ -24,8 +24,8 @@ import org.mozilla.jss.crypto.KeyGenAlgorithm;
 import org.mozilla.jss.crypto.KeyGenerator;
 import org.mozilla.jss.crypto.SymmetricKey;
 import org.mozilla.jss.crypto.TokenException;
+import org.mozilla.jss.netscape.security.util.Utils;
 
-import com.netscape.certsrv.apps.CMS;
 import com.netscape.certsrv.base.BadRequestException;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
@@ -37,23 +37,30 @@ import com.netscape.certsrv.system.TPSConnectorCollection;
 import com.netscape.certsrv.system.TPSConnectorData;
 import com.netscape.certsrv.system.TPSConnectorResource;
 import com.netscape.certsrv.tps.cert.TPSCertResource;
-import com.netscape.certsrv.usrgrp.IUGSubsystem;
 import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.servlet.base.PKIService;
+import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import com.netscape.cmsutil.util.Utils;
 
 public class TPSConnectorService extends PKIService implements TPSConnectorResource {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(TPSConnectorService.class);
+
     private static final String TPS_LIST = "tps.list";
 
-    IConfigStore cs = CMS.getConfigStore();
+    CMSEngine engine = CMS.getCMSEngine();
+    IConfigStore cs = engine.getConfigStore();
 
-    public IUGSubsystem userGroupManager = (IUGSubsystem) CMS.getSubsystem(CMS.SUBSYSTEM_UG);
+    public UGSubsystem userGroupManager = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
 
     @Override
-    public Response findConnectors(Integer start, Integer size) {
+    public Response findConnectors(String host, String port, Integer start, Integer size) {
         try {
+            start = start == null ? 0 : start;
+            size = size == null ? DEFAULT_SIZE : size;
+
             String tpsList = cs.getString(TPS_LIST, "");
             Iterator<String> entries = Arrays.asList(StringUtils.split(tpsList, ",")).iterator();
 
@@ -66,7 +73,17 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
             // return entries up to the page size
             for (; i < start + size && entries.hasNext(); i++) {
-                response.addEntry(createTPSConnectorData(entries.next()));
+                TPSConnectorData connector = createTPSConnectorData(entries.next());
+
+                if (host != null && !host.equals(connector.getHost())) {
+                    continue;
+                }
+
+                if (port != null && !port.equals(connector.getPort())) {
+                    continue;
+                }
+
+                response.addEntry(connector);
             }
 
             // count the total entries
@@ -87,20 +104,23 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createOKResponse(response);
 
         } catch (EBaseException e) {
-            e.printStackTrace();
-            throw new PKIException("Unable to get TPS connection data: " + e);
+            logger.error("TPSConnectorService: Unable to find TPS connectors: " + e.getMessage(), e);
+            throw new PKIException("Unable to find TPS connectors: " + e.getMessage(), e);
         }
     }
 
     private TPSConnectorData createTPSConnectorData(String tpsID) throws EBaseException {
+
         TPSConnectorData data = new TPSConnectorData();
         data.setID(tpsID);
         data.setHost(cs.getString("tps." + tpsID + ".host", ""));
         data.setPort(cs.getString("tps." + tpsID + ".port", ""));
         data.setUserID(cs.getString("tps." + tpsID + ".userid", ""));
         data.setNickname(cs.getString("tps." + tpsID + ".nickname", ""));
+
         URI uri = uriInfo.getBaseUriBuilder().path(TPSCertResource.class).path("{id}").build(tpsID);
         data.setLink(new Link("self", uri));
+
         return data;
     }
 
@@ -121,30 +141,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createTPSConnectorData(id);
 
         } catch (EBaseException e) {
-            e.printStackTrace();
-            throw new PKIException("Unable to get TPS connection data" + e);
-        }
-    }
-
-    @Override
-    public Response getConnector(String host, String port) {
-
-        if (host == null)
-            throw new BadRequestException("TPS connector host is null.");
-        if (port == null)
-            throw new BadRequestException("TPS connector port is null.");
-
-        try {
-            String id = getConnectorID(host, port);
-            if (id == null)
-                throw new ResourceNotFoundException(
-                        "Connector not found for " + host + ":" + port);
-
-            return createOKResponse(createTPSConnectorData(id));
-
-        } catch (EBaseException e) {
-            e.printStackTrace();
-            throw new PKIException("Unable to get TPS connection data" + e);
+            logger.error("TPSConnectorService: Unable to get TPS connector: " + e.getMessage(), e);
+            throw new PKIException("Unable to get TPS connector: " + e.getMessage(), e);
         }
     }
 
@@ -180,9 +178,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createCreatedResponse(newData, newData.getLink().getHref());
 
         } catch (EBaseException e) {
-            CMS.debug("Unable to create new TPS Connector: " + e);
-            e.printStackTrace();
-            throw new PKIException("Unable to create  new TPS connector: " + e);
+            logger.error("TPSConnectorService: Unable to create new TPS connector: " + e.getMessage(), e);
+            throw new PKIException("Unable to create new TPS connector: " + e.getMessage(), e);
         }
     }
 
@@ -217,16 +214,15 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createOKResponse(curData);
 
         } catch (EBaseException e) {
-            CMS.debug("Unable to modify TPS Connector: " + e);
-            e.printStackTrace();
-            throw new PKIException("Unable to modify TPS Connector: " + e);
+            logger.error("TPSConnectorService: Unable to modify TPS connector: " + e.getMessage(), e);
+            throw new PKIException("Unable to modify TPS connector: " + e.getMessage(), e);
         }
     }
 
     private void saveClientData(TPSConnectorData newData) throws EBaseException {
         String id = newData.getID();
         if (StringUtils.isEmpty(id)) {
-            CMS.debug("saveClientData: Attempt to save tps connection with null or empty id");
+            logger.warn("TPSConnectorService: Attempt to save tps connection with null or empty id");
             return;
         }
         String prefix = "tps." + id + ".";
@@ -258,8 +254,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createNoContentResponse();
 
         } catch (EBaseException e) {
-            e.printStackTrace();
-            throw new PKIException("Failed to delete TPS connection" + e);
+            logger.error("TPSConnectorService: Failed to delete TPS connector: " + e.getMessage(), e);
+            throw new PKIException("Failed to delete TPS connector: " + e.getMessage(), e);
         }
     }
 
@@ -276,8 +272,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             id = getConnectorID(host, port);
             deleteConnector(id);
         } catch (EBaseException e) {
-            e.printStackTrace();
-            throw new PKIException("Failed to delete TPS connector: " + e);
+            logger.error("TPSConnectorService: Failed to delete TPS connector: " + e.getMessage(), e);
+            throw new PKIException("Failed to delete TPS connector: " + e.getMessage(), e);
         }
 
         return createNoContentResponse();
@@ -286,7 +282,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response createSharedSecret(String id) {
 
-        CMS.debug("TPSConnectorService.createSharedSecret.id: " + id);
+        logger.debug("TPSConnectorService.createSharedSecret.id: " + id);
 
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
@@ -302,12 +298,12 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             // get user cert
             IUser user = userGroupManager.getUser(userid);
 
-            CMS.debug("TPSConnectorService.createSharedSecret.userid: " + userid);
+            logger.debug("TPSConnectorService.createSharedSecret.userid: " + userid);
             X509Certificate[] certs = user.getX509Certificates();
 
             String nickname = userid + " sharedSecret";
 
-            CMS.debug("TPSConnectorService.createSharedSecret. nickname: " + nickname);
+            logger.debug("TPSConnectorService.createSharedSecret. nickname: " + nickname);
             if (CryptoUtil.sharedSecretExists(nickname)) {
                 throw new BadRequestException("Shared secret already exists");
             }
@@ -336,9 +332,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createOKResponse(keyData);
 
         } catch (Exception  e) {
-            e.printStackTrace();
-            CMS.debug("Error in generating and exporting shared secret: " + e);
-            throw new PKIException("Error in generating and exporting shared secret: " + e, e);
+            logger.error("TPSConnectorService: Unable to generate and export shared secret: " + e.getMessage(), e);
+            throw new PKIException("Unable to generate and export shared secret: " + e.getMessage(), e);
         }
     }
 
@@ -405,9 +400,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createOKResponse(keyData);
 
         } catch (Exception e) {
-            e.printStackTrace();
-            CMS.debug("Error in replacing shared secret: " + e);
-            throw new PKIException("Error in replacing shared secret: " + e, e);
+            logger.error("TPSConnectorService: Unable to replace shared secret: " + e.getMessage(), e);
+            throw new PKIException("Unable to replace shared secret: " + e.getMessage(), e);
         }
     }
 
@@ -441,9 +435,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
         } catch (InvalidKeyException | IllegalStateException | EBaseException
                 | NotInitializedException | TokenException e) {
-            e.printStackTrace();
-            CMS.debug("Error in deleting shared secret: " + e);
-            throw new PKIException("Error in deleting shared secret: " + e);
+            logger.error("TPSConnectorService: Unable to delete shared secret: " + e.getMessage(), e);
+            throw new PKIException("Unable to delete shared secret: " + e.getMessage(), e);
         }
     }
 
@@ -453,7 +446,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
 
-        CMS.debug("TPSConnectorServlet.getSharedSecret: id : " + id);
+        logger.debug("TPSConnectorServlet.getSharedSecret: id : " + id);
         try {
             if (!connectorExists(id)) {
                 throw new ResourceNotFoundException("TPS connection does not exist");
@@ -489,9 +482,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             return createOKResponse(keyData);
 
         } catch (Exception e) {
-            e.printStackTrace();
-            CMS.debug("Error in obtaining shared secret: " + e);
-            throw new PKIException("Error in obtaining shared secret: " + e, e);
+            logger.error("TPSConnectorService: Unable to obtain shared secret: " + e.getMessage(), e);
+            throw new PKIException("Unable to obtain shared secret: " + e.getMessage(), e);
         }
     }
 
@@ -556,12 +548,10 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             tempKey = kg.generate();
         } catch (NoSuchAlgorithmException | TokenException | IllegalStateException | CharConversionException
                 | NotInitializedException e) {
-            CMS.debug("TPSConnectorService.createDes3SesisonKeyOnInternal: Can't generate temporary session key.");
-
-            throw new EBaseException(e);
+            logger.error("TPSConnectorService: Unable to generate temporary session key: " + e.getMessage(), e);
+            throw new EBaseException("Unable to generate temporary session key: " + e.getMessage(), e);
         }
 
         return tempKey;
     }
-
 }
